@@ -1,6 +1,5 @@
 #' @include coclusterStrategy.R
 #' @include optionclasses.R
-#' @include Rcoclust.R
 #' 
 NULL
 
@@ -33,6 +32,8 @@ NULL
 #' 
 #' @param nbcocluster Integer vector specifying the number of row and column clusters respectively.
 #' @param strategy Object of class \code{\linkS4class{strategy}}.
+#' @param nbCore number of thread to use (OpenMP must be available), 0 for all cores. Default value is 1.
+
 #' @return Return an object of \code{\linkS4class{BinaryOptions}}.
 #' 
 #' @export
@@ -55,7 +56,7 @@ NULL
 #' 
 coclusterBinary<-function( data, semisupervised = FALSE, rowlabels = numeric(0), collabels = numeric(0),
                            model = NULL, nbcocluster, strategy = coclusterStrategy(), a=1, b=1
-                         ) 
+											   , nbCore = 1) 
 {
 	#Check for data
 	if(missing(data)){ stop("Data is missing.")}
@@ -142,6 +143,8 @@ coclusterBinary<-function( data, semisupervised = FALSE, rowlabels = numeric(0),
 	# checking for hyperparameters
   if ((a <=0)||(b<=0)) { stop("hyper-parameters must be positive")}
   #strategy@hyperparam = c(a,b);
+	#  check nbCore
+	if(!is.numeric(nbCore) && length(nbCore) != 1) stop("nbCore must be an integer")
   # create object
   inpobj<-new( "BinaryOptions",data = data
 	           , rowlabels = rowlabels, collabels = collabels
@@ -150,7 +153,7 @@ coclusterBinary<-function( data, semisupervised = FALSE, rowlabels = numeric(0),
 					   , strategy = strategy
 				     , hyperparam = c(a,b))
 
-  .Call("CoClustmain",inpobj,PACKAGE = "blockcluster")
+  .Call("CoClustmain",inpobj, nbCore,PACKAGE = "blockcluster")
   cat(inpobj@message,"\n")
   return(inpobj)
 }
